==> zio-aws-iotfleetwise_2.13-5.20.22.2-sources.jar: zio/aws/iotfleetwise/model/DeleteCampaignResponse.scala <==
package zio.aws.iotfleetwise.model
import zio.aws.iotfleetwise.model.primitives.{Arn, CampaignName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteCampaignResponse(
    name: Optional[CampaignName] = Optional.Absent,
    arn: Optional[Arn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse = {
    import DeleteCampaignResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse
      .builder()
      .optionallyWith(
        name.map(value => CampaignName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .build()
  }
  def asReadOnly: zio.aws.iotfleetwise.model.DeleteCampaignResponse.ReadOnly =
    zio.aws.iotfleetwise.model.DeleteCampaignResponse.wrap(buildAwsValue())
}
object DeleteCampaignResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotfleetwise.model.DeleteCampaignResponse =
      zio.aws.iotfleetwise.model.DeleteCampaignResponse(
        name.map(value => value),
        arn.map(value => value)
      )
    def name: Optional[CampaignName]
    def arn: Optional[Arn]
    def getName: ZIO[Any, AwsError, CampaignName] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse
  ) extends zio.aws.iotfleetwise.model.DeleteCampaignResponse.ReadOnly {
    override val name: Optional[CampaignName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.iotfleetwise.model.primitives.CampaignName(value))
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.iotfleetwise.model.primitives.Arn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse
  ): zio.aws.iotfleetwise.model.DeleteCampaignResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iotfleetwise_3-7.21.15.9-sources.jar: zio/aws/iotfleetwise/model/DeleteCampaignResponse.scala <==
package zio.aws.iotfleetwise.model
import zio.aws.iotfleetwise.model.primitives.{Arn, CampaignName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeleteCampaignResponse(
    name: Optional[CampaignName] = Optional.Absent,
    arn: Optional[Arn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse = {
    import DeleteCampaignResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse
      .builder()
      .optionallyWith(
        name.map(value => CampaignName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .build()
  }
  def asReadOnly: zio.aws.iotfleetwise.model.DeleteCampaignResponse.ReadOnly =
    zio.aws.iotfleetwise.model.DeleteCampaignResponse.wrap(buildAwsValue())
}
object DeleteCampaignResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotfleetwise.model.DeleteCampaignResponse =
      zio.aws.iotfleetwise.model.DeleteCampaignResponse(
        name.map(value => value),
        arn.map(value => value)
      )
    def name: Optional[CampaignName]
    def arn: Optional[Arn]
    def getName: ZIO[Any, AwsError, CampaignName] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse
  ) extends zio.aws.iotfleetwise.model.DeleteCampaignResponse.ReadOnly {
    override val name: Optional[CampaignName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.iotfleetwise.model.primitives.CampaignName(value))
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.iotfleetwise.model.primitives.Arn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotfleetwise.model.DeleteCampaignResponse
  ): zio.aws.iotfleetwise.model.DeleteCampaignResponse.ReadOnly = new Wrapper(
    impl
  )
}
